<?php



/**
 * Funkce pro odstraneni diakritiky z retezce v UTF-8
 *
 * Nahradi vsechna pismena s diakritikou za jejich ekvivalenty bez diakritiky.
 * @param string $utf8String
 */
function utf82ascii($utf8String) {
	
	static $asciiArray = array('A','A','A','A','A','A','C','E','E','E','E','I','I','I','I','D','N',
		'O','O','O','O','O','O','U','U','U','U','Y','a','a','a','a','a','a','c','e','e','e','e',
		'i','i','i','i','n','o','o','o','o','o','o','u','u','u','u','y','y','A','a','A','a','A','a',
		'C','c','C','c','C','c','C','c','D','d','D','d','E','e','E','e','E','e','E','e','E','e',
		'G','g','G','g','G','g','G','g','H','h','H','h','I','i','I','i','I','i','I','i','I','i',
		'J','j','K','k','k','L','l','L','l','L','l','L','l','L','l','N','n','N','n','N','n','n',
		'O','o','O','o','O','o','R','r','R','r','R','r','S','s','S','s','S','s','S','s',
		'T','t','T','t','U','u','U','u','U','u','U','u','U','u','U','u','W','w','Y','y','Y',
		'Z','z','Z','z','Z','z','A','a','U','u','I','i','O','o','U','u','U','u','U','u','U','u',
		'U','u','A','a');

	static $utf8Array = array("\xc3\x80", "\xc3\x81", "\xc3\x82", "\xc3\x83", "\xc3\x84", "\xc3\x85",
		"\xc3\x87", "\xc3\x88", "\xc3\x89", "\xc3\x8a", "\xc3\x8b", "\xc3\x8c", "\xc3\x8d",
		"\xc3\x8e", "\xc3\x8f", "\xc3\x90", "\xc3\x91", "\xc3\x92", "\xc3\x93", "\xc3\x94",
		"\xc3\x95", "\xc3\x96", "\xc3\x98", "\xc3\x99", "\xc3\x9a", "\xc3\x9b", "\xc3\x9c",
		"\xc3\x9d", "\xc3\xa0", "\xc3\xa1", "\xc3\xa2", "\xc3\xa3", "\xc3\xa4", "\xc3\xa5",
		"\xc3\xa7", "\xc3\xa8", "\xc3\xa9", "\xc3\xaa", "\xc3\xab", "\xc3\xac", "\xc3\xad",
		"\xc3\xae", "\xc3\xaf", "\xc3\xb1", "\xc3\xb2", "\xc3\xb3", "\xc3\xb4", "\xc3\xb5",
		"\xc3\xb6", "\xc3\xb8", "\xc3\xb9", "\xc3\xba", "\xc3\xbb", "\xc3\xbc", "\xc3\xbd",
		"\xc3\xbf", "\xc4\x80", "\xc4\x81", "\xc4\x82", "\xc4\x83", "\xc4\x84", "\xc4\x85",
		"\xc4\x86", "\xc4\x87", "\xc4\x88", "\xc4\x89", "\xc4\x8a", "\xc4\x8b", "\xc4\x8c",
		"\xc4\x8d", "\xc4\x8e", "\xc4\x8f", "\xc4\x90", "\xc4\x91", "\xc4\x92", "\xc4\x93",
		"\xc4\x94", "\xc4\x95", "\xc4\x96", "\xc4\x97", "\xc4\x98", "\xc4\x99", "\xc4\x9a",
		"\xc4\x9b", "\xc4\x9c", "\xc4\x9d", "\xc4\x9e", "\xc4\x9f", "\xc4\xa0", "\xc4\xa1",
		"\xc4\xa2", "\xc4\xa3", "\xc4\xa4", "\xc4\xa5", "\xc4\xa6", "\xc4\xa7", "\xc4\xa8",
		"\xc4\xa9", "\xc4\xaa", "\xc4\xab", "\xc4\xac", "\xc4\xad", "\xc4\xae", "\xc4\xaf",
		"\xc4\xb0", "\xc4\xb1", "\xc4\xb4", "\xc4\xb5", "\xc4\xb6", "\xc4\xb7", "\xc4\xb8",
		"\xc4\xb9", "\xc4\xba", "\xc4\xbb", "\xc4\xbc", "\xc4\xbd", "\xc4\xbe", "\xc4\xbf",
		"\xc5\x80", "\xc5\x81", "\xc5\x82", "\xc5\x83", "\xc5\x84", "\xc5\x85", "\xc5\x86",
		"\xc5\x87", "\xc5\x88", "\xc5\x89", "\xc5\x8c", "\xc5\x8d", "\xc5\x8e", "\xc5\x8f",
		"\xc5\x90", "\xc5\x91", "\xc5\x94", "\xc5\x95", "\xc5\x96", "\xc5\x97", "\xc5\x98",
		"\xc5\x99", "\xc5\x9a", "\xc5\x9b", "\xc5\x9c", "\xc5\x9d", "\xc5\x9e", "\xc5\x9f",
		"\xc5\xa0", "\xc5\xa1", "\xc5\xa2", "\xc5\xa3", "\xc5\xa4", "\xc5\xa5", "\xc5\xa8",
		"\xc5\xa9", "\xc5\xaa", "\xc5\xab", "\xc5\xac", "\xc5\xad", "\xc5\xae", "\xc5\xaf",
		"\xc5\xb0", "\xc5\xb1", "\xc5\xb2", "\xc5\xb3", "\xc5\xb4", "\xc5\xb5", "\xc5\xb6",
		"\xc5\xb7", "\xc5\xb8", "\xc5\xb9", "\xc5\xba", "\xc5\xbb", "\xc5\xbc", "\xc5\xbd",
		"\xc5\xbe", "\xc7\x8d", "\xc7\x8e", "\xc6\xaf", "\xc6\xb0", "\xc7\x8f", "\xc7\x90",
		"\xc7\x91", "\xc7\x92", "\xc7\x93", "\xc7\x94", "\xc7\x95", "\xc7\x96", "\xc7\x97",
		"\xc7\x98", "\xc7\x99", "\xc7\x9a", "\xc7\x9b", "\xc7\x9c", "\xc7\xba", "\xc7\xbb");
	
	return str_replace($utf8Array, $asciiArray, $utf8String);
}

?>
