--
-- Databáze: [prefix][ID_SYSTEMU]
--

CREATE TABLE IF NOT EXISTS `bankovni_ucet` (
  `bankovni_ucet_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `cislo_uctu` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  `kod_banky` varchar(4) COLLATE utf8_czech_ci NOT NULL,
  `iban` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  `swift` varchar(11) COLLATE utf8_czech_ci DEFAULT NULL,
  `aktivni` tinyint(4) NOT NULL DEFAULT '0',
  `parovat` tinyint(4) NOT NULL DEFAULT '0',
  `value1` varchar(255) COLLATE utf8_czech_ci DEFAULT NULL,
  `value2` varchar(255) COLLATE utf8_czech_ci DEFAULT NULL,
  `mena_id` int(11) NOT NULL DEFAULT '1',
  `popis` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  PRIMARY KEY (`bankovni_ucet_id`)
);

CREATE TABLE IF NOT EXISTS `ciselna_rada` (
  `ciselna_rada_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(200) COLLATE utf8_czech_ci NOT NULL,
  `format` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `ciselnik` int(11) NOT NULL DEFAULT '0',
  `typ` tinyint(4) NOT NULL,
  `posledni_faktura` int(11) NOT NULL,
  PRIMARY KEY (`ciselna_rada_id`),
  KEY `posledni_faktura` (`posledni_faktura`)
);

INSERT INTO `ciselna_rada` (`ciselna_rada_id`, `nazev`, `format`, `ciselnik`, `typ`, `posledni_faktura`) VALUES
(1, '', '#ROK##NNNNN#', 1, 1, 0),
(2, '', 'PF#NNNNNN#', 1, 2, 0),
(3, '', 'PD#NNN#', 1, 3, 0);

CREATE TABLE IF NOT EXISTS `event` (
  `event_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(300) COLLATE utf8_czech_ci NOT NULL,
  `class` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `object_id` int(11) DEFAULT NULL,
  `only_admin` tinyint(4) NOT NULL DEFAULT '1',
  `time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `user_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`event_id`)
);

CREATE TABLE IF NOT EXISTS `faktura` (
  `faktura_id` int(11) NOT NULL AUTO_INCREMENT,
  `user_id` int(11) DEFAULT NULL,
  `razitko_id` int(11) NOT NULL DEFAULT '1',
  `cislo_faktury` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  `cislo_objednavky` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `odberatel` int(11) NOT NULL,
  `dodavatel` int(11) NOT NULL,
  `platba` tinyint(4) NOT NULL,
  `datum_vystaveni` date NOT NULL,
  `datum_splatnosti` date NOT NULL,
  `datum_plneni` date DEFAULT NULL,
  `zaplacena` tinyint(4) NOT NULL DEFAULT '0',
  `doklad` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `vs` decimal(10,0) DEFAULT NULL,
  `zamcena` tinyint(4) NOT NULL DEFAULT '0',
  `bankovni_ucet_id` int(11) DEFAULT NULL,
  `paticka_id` int(11) DEFAULT NULL,
  `is_proforma` tinyint(4) NOT NULL DEFAULT '0',
  `platce_dph` tinyint(1) NOT NULL DEFAULT '0',
  `mena_id` int(11) NOT NULL DEFAULT '1',
  `logo_id` int(11) DEFAULT NULL,
  `poznamka` varchar(255) COLLATE utf8_czech_ci DEFAULT NULL,
  `interni_poznamka` varchar(255) COLLATE utf8_czech_ci DEFAULT NULL,
  `kurz` float NOT NULL DEFAULT '1',
  `datum_uhrady` date DEFAULT NULL,
  `sazby_dph` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `specialni_rezim_export` tinyint(1) NOT NULL DEFAULT '0',
  `zaloha` decimal(10,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (`faktura_id`),
  KEY `user_id` (`user_id`),
  KEY `razitko_id` (`razitko_id`),
  KEY `bankovni_ucet_id` (`bankovni_ucet_id`),
  KEY `paticka_id` (`paticka_id`)
);

CREATE TABLE IF NOT EXISTS `faktura_bankovni_ucet` (
  `faktura_id` int(11) NOT NULL,
  `bankovni_ucet_id` int(11) NOT NULL,
  PRIMARY KEY (`faktura_id`,`bankovni_ucet_id`)
);

CREATE TABLE IF NOT EXISTS `faktura_proforma` (
  `proforma_faktura_id` int(11) NOT NULL,
  `proforma_id` int(11) NOT NULL,
  PRIMARY KEY (`proforma_faktura_id`,`proforma_id`)
);

CREATE TABLE IF NOT EXISTS `kontakt` (
  `kontakt_id` int(11) NOT NULL AUTO_INCREMENT,
  `user_id` int(11) DEFAULT NULL,
  `nazev` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `ulice` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `mesto` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `psc` varchar(6) COLLATE utf8_czech_ci NOT NULL,
  `ico` varchar(10) COLLATE utf8_czech_ci DEFAULT NULL,
  `dic` varchar(20) COLLATE utf8_czech_ci DEFAULT NULL,
  `email` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  `www` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  `telefon` varchar(20) COLLATE utf8_czech_ci DEFAULT NULL,
  `typ_kontaktu_id` int(11) NOT NULL DEFAULT '1',
  `zeme` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  PRIMARY KEY (`kontakt_id`),
  KEY `user_id` (`user_id`),
  KEY `typ_kontaktu_id` (`typ_kontaktu_id`)
);

CREATE TABLE IF NOT EXISTS `mena` (
  `mena_id` int(11) NOT NULL AUTO_INCREMENT,
  `kod` varchar(3) COLLATE utf8_czech_ci NOT NULL,
  `symbol` varchar(10) COLLATE utf8_czech_ci NOT NULL,
  `zaokrouhleni` int(11) NOT NULL,
  `vychozi` int(11) NOT NULL,
  `kurz` float NOT NULL DEFAULT '1',
  `platnost_kurzu` datetime DEFAULT NULL,
  PRIMARY KEY (`mena_id`),
  UNIQUE KEY `kod` (`kod`)
);

INSERT INTO `mena` (`mena_id`, `kod`, `symbol`, `zaokrouhleni`, `vychozi`, `kurz`, `platnost_kurzu`) VALUES
(1, 'CZK', 'Kč', 0, 1, 1, NULL),
(2, 'EUR', 'EUR', 2, 0, 24.84, NULL);

CREATE TABLE IF NOT EXISTS `nastaveni` (
  `nazev` varchar(20) COLLATE utf8_czech_ci NOT NULL,
  `bool_hodnota` tinyint(1) DEFAULT NULL,
  `string_hodnota` varchar(200) COLLATE utf8_czech_ci DEFAULT NULL,
  `int_hodnota` int(11) DEFAULT NULL,
  PRIMARY KEY (`nazev`)
);

INSERT INTO `nastaveni` (`nazev`, `bool_hodnota`, `string_hodnota`, `int_hodnota`) VALUES
('platce_dph', 1, '', NULL),
('nazev', NULL, 'UTB.cz', NULL),
('mail_for_bot', NULL, 'nejaky@email.cz', NULL),
('aktualizovat_meny', NULL, NULL, 2),
('system_design', NULL, NULL, 1);

CREATE TABLE IF NOT EXISTS `obrazek_faktura` (
  `obrazek_faktura_id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) CHARACTER SET utf8_czech_ci NOT NULL,
  `sirka` int(11) NOT NULL,
  `vyska` int(11) NOT NULL,
  `mime_typ` varchar(30) CHARACTER SET utf8_czech_ci NOT NULL,
  `image` blob NOT NULL,
  `aktualni` tinyint(4) NOT NULL DEFAULT '1',
  `typ` varchar(200) COLLATE utf8_czech_ci NOT NULL DEFAULT 'razitko',
  PRIMARY KEY (`obrazek_faktura_id`)
);

CREATE TABLE IF NOT EXISTS `paticka` (
  `paticka_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(200) COLLATE utf8_czech_ci NOT NULL,
  `aktivni` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`paticka_id`)
);

CREATE TABLE IF NOT EXISTS `polozka` (
  `polozka_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(200) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`polozka_id`)
);

CREATE TABLE IF NOT EXISTS `polozka_faktura` (
  `polozka_faktura_id` int(11) NOT NULL AUTO_INCREMENT,
  `cena` float NOT NULL,
  `od` date DEFAULT NULL,
  `do` date DEFAULT NULL,
  `ks` int(11) DEFAULT NULL,
  `zbozi_id` int(11) DEFAULT NULL,
  `polozka` int(11) NOT NULL,
  `faktura_id` int(11) NOT NULL,
  `dph` float NOT NULL DEFAULT '0',
  `sazba_dph_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`polozka_faktura_id`),
  KEY `polozka_id` (`polozka`),
  KEY `zbozi_id` (`zbozi_id`)
);

CREATE TABLE IF NOT EXISTS `razitko` (
  `razitko_id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `sirka` int(11) NOT NULL,
  `vyska` int(11) NOT NULL,
  `mime_typ` varchar(30) COLLATE utf8_czech_ci NOT NULL,
  `image` blob NOT NULL,
  `aktualni` tinyint(4) NOT NULL DEFAULT '1',
  PRIMARY KEY (`razitko_id`)
);

CREATE TABLE IF NOT EXISTS `sazba_dph` (
  `sazba_dph_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `sazba` float NOT NULL,
  `vychozi` tinyint(1) NOT NULL,
  PRIMARY KEY (`sazba_dph_id`)
) AUTO_INCREMENT=4;

INSERT INTO `sazba_dph` (`sazba_dph_id`, `nazev`, `sazba`, `vychozi`) VALUES
(1, 'základní sazba', 21, 1),
(2, 'snížená sazba', 15, 0),
(3, 'zvláštní režim', 0, 0);

CREATE TABLE IF NOT EXISTS `sklad` (
  `sklad_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(255) COLLATE utf8_czech_ci NOT NULL,
  `xml_for_update` varchar(255) COLLATE utf8_czech_ci DEFAULT NULL,
  PRIMARY KEY (`sklad_id`)
);

CREATE TABLE IF NOT EXISTS `sluzba` (
  `sluzba_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(200) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`sluzba_id`)
);

CREATE TABLE IF NOT EXISTS `sluzba_user` (
  `sluzba_user_id` int(11) NOT NULL AUTO_INCREMENT,
  `sluzba_id` int(11) NOT NULL,
  `user_id` int(11) NOT NULL,
  `od` date DEFAULT NULL,
  `do` date DEFAULT NULL,
  `faktura_id` int(11) DEFAULT NULL,
  `domena` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `faktura_vystavena` tinyint(4) NOT NULL DEFAULT '0',
  `cena` int(11) NOT NULL,
  `obdobi` int(11) DEFAULT NULL,
  `predem_dni` int(11) NOT NULL DEFAULT '26',
  PRIMARY KEY (`sluzba_user_id`)
);

CREATE TABLE IF NOT EXISTS `soubor` (
  `soubor_id` int(11) NOT NULL,
  `name` varchar(255) COLLATE utf8_czech_ci NOT NULL,
  `mime_typ` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  `data` longblob NOT NULL,
  `time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`soubor_id`)
);

CREATE TABLE IF NOT EXISTS `transakce` (
  `transakce_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `popis` text COLLATE utf8_czech_ci NOT NULL,
  `datum` datetime NOT NULL,
  `castka` float NOT NULL,
  `faktura_id` int(11) DEFAULT NULL,
  `vydaj_id` int(11) DEFAULT NULL,
  `hash` varchar(32) COLLATE utf8_czech_ci NOT NULL,
  `vs` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `bankovni_ucet_id` int(11) NOT NULL,
  `interni` tinyint(1) NOT NULL DEFAULT '0',
  `kurz` float NOT NULL DEFAULT '1',
  PRIMARY KEY (`transakce_id`),
  UNIQUE KEY `hash` (`hash`),
  KEY `faktura_id` (`faktura_id`),
  KEY `bankovni_ucet_id` (`bankovni_ucet_id`)
);

CREATE TABLE IF NOT EXISTS `typ_kontaktu` (
  `typ_kontaktu_id` int(11) NOT NULL,
  `nazev` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`typ_kontaktu_id`)
);

INSERT INTO `typ_kontaktu` (`typ_kontaktu_id`, `nazev`) VALUES
(1, 'normální');

CREATE TABLE IF NOT EXISTS `typ_platby` (
  `typ_platby_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(255) COLLATE utf8_czech_ci NOT NULL,
  `faktura_nazev` varchar(255) COLLATE utf8_czech_ci NOT NULL,
  `pro_vydaje` tinyint(4) NOT NULL DEFAULT '0',
  `pro_prijmy` tinyint(4) NOT NULL DEFAULT '0',
  `povinna` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`typ_platby_id`)
);

INSERT INTO `typ_platby` (`typ_platby_id`, `nazev`, `faktura_nazev`, `pro_vydaje`, `pro_prijmy`, `povinna`) VALUES
(0, 'Hotově', 'Hotově', 1, 1, 1),
(1, 'Převodem', 'Bankovním převodem', 1, 1, 1),
(3, 'Plat.kartou', 'Platební kartou', 1, 1, 0),
(2, 'Dobírkou', 'Dobírkou', 0, 1, 0);

CREATE TABLE IF NOT EXISTS `ucet` (
  `ucet_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  `predcisli` varchar(10) COLLATE utf8_czech_ci DEFAULT NULL,
  `cislo_uctu` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `kod_banky` varchar(4) COLLATE utf8_czech_ci DEFAULT NULL,
  `iban` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  `swift` varchar(11) COLLATE utf8_czech_ci DEFAULT NULL,
  `mena_id` int(11) NOT NULL DEFAULT '1',
  `popis` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  PRIMARY KEY (`ucet_id`)
);

CREATE TABLE IF NOT EXISTS `user` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `email` varchar(128) COLLATE utf8_czech_ci NOT NULL DEFAULT '',
  `passw` varchar(32) COLLATE utf8_czech_ci NOT NULL DEFAULT '',
  `opravneni` int(10) NOT NULL DEFAULT '2',
  `session` varchar(32) COLLATE utf8_czech_ci NOT NULL DEFAULT '',
  `ip` varchar(15) COLLATE utf8_czech_ci NOT NULL DEFAULT '',
  `lasttime` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `kontakt_id` int(11) DEFAULT NULL,
  `system_user` tinyint(4) NOT NULL DEFAULT '0',
  `xml` text COLLATE utf8_czech_ci,
  `doba_dodani` int(11) DEFAULT NULL,
  `mail_typ` varchar(150) COLLATE utf8_czech_ci DEFAULT NULL,
  `mail_sklad` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `xml_typ` varchar(20) COLLATE utf8_czech_ci DEFAULT NULL,
  `dodavatel_platce_dph` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `email` (`email`),
  KEY `kontakt_id` (`kontakt_id`)
);

--
-- Vypisuji data pro tabulku `user`
--

INSERT INTO `user` (`id`, `email`, `passw`, `opravneni`, `session`, `ip`, `lasttime`, `kontakt_id`, `system_user`, `xml`, `doba_dodani`, `mail_typ`, `mail_sklad`, `xml_typ`, `dodavatel_platce_dph`) VALUES
(1, 'zadkladni@admin.cz', 'MD5-HESLO', 2, '', '', '0000-00-00 00:00:00', NULL, 1, NULL, NULL, NULL, NULL, NULL, 0);

CREATE TABLE IF NOT EXISTS `user_types` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`)
) AUTO_INCREMENT=3;

INSERT INTO `user_types` (`id`, `nazev`) VALUES
(1, 'Admin'),
(2, 'Uživatel'),
(-1, 'Dodavatel');

CREATE TABLE IF NOT EXISTS `user_ucet` (
  `user_id` int(11) NOT NULL,
  `ucet_id` int(11) NOT NULL,
  PRIMARY KEY (`user_id`,`ucet_id`)
);

CREATE TABLE IF NOT EXISTS `vydaj` (
  `vydaj_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(255) COLLATE utf8_czech_ci NOT NULL,
  `cislo_dokladu` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `cislo_proformy` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `dodavatel_nazev` varchar(255) COLLATE utf8_czech_ci DEFAULT NULL,
  `dodavatel_id` int(11) DEFAULT NULL,
  `typ_platby_id` int(11) NOT NULL,
  `datum_vystaveni` date NOT NULL,
  `datum_splatnosti` date DEFAULT NULL,
  `datum_plneni` date DEFAULT NULL,
  `datum_uhrady` date DEFAULT NULL,
  `uhrazeno` tinyint(4) NOT NULL DEFAULT '0',
  `vs` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `kurz` float NOT NULL DEFAULT '1',
  `poznamka` varchar(255) COLLATE utf8_czech_ci DEFAULT NULL,
  `castka_bez_dph` decimal(10,2) DEFAULT NULL,
  `castka` decimal(10,2) DEFAULT NULL,
  `mena_id` int(11) NOT NULL,
  `dodavatel_platce_dph` tinyint(1) DEFAULT NULL,
  `ks` varchar(4) COLLATE utf8_czech_ci DEFAULT NULL,
  `ss` varchar(15) COLLATE utf8_czech_ci DEFAULT NULL,
  PRIMARY KEY (`vydaj_id`)
);

CREATE TABLE IF NOT EXISTS `vydaj_soubor` (
  `vydaj_id` int(11) NOT NULL,
  `soubor_id` int(11) NOT NULL,
  PRIMARY KEY (`vydaj_id`,`soubor_id`)
);

CREATE TABLE IF NOT EXISTS `vydaj_ucet` (
  `vydaj_id` int(11) NOT NULL,
  `ucet_id` int(11) NOT NULL,
  PRIMARY KEY (`vydaj_id`,`ucet_id`)
);

CREATE TABLE IF NOT EXISTS `vyrobce` (
  `vyrobce_id` int(11) NOT NULL AUTO_INCREMENT,
  `nazev` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`vyrobce_id`),
  UNIQUE KEY `nazev` (`nazev`)
);

CREATE TABLE IF NOT EXISTS `zbozi` (
  `zbozi_id` int(11) NOT NULL AUTO_INCREMENT,
  `typ_zbozi_id` int(11) NOT NULL DEFAULT '0',
  `nazev` varchar(255) COLLATE utf8_czech_ci NOT NULL,
  `model` varchar(50) COLLATE utf8_czech_ci DEFAULT NULL,
  `nakupni_cena` float DEFAULT NULL,
  `prodejni_cena` float DEFAULT NULL,
  `bezna_cena` float DEFAULT NULL,
  `ean` varchar(30) COLLATE utf8_czech_ci DEFAULT NULL,
  `externi_id` int(11) DEFAULT NULL,
  `img_url` varchar(200) COLLATE utf8_czech_ci DEFAULT NULL,
  `img_thumb_data` blob,
  `img_thumb_time` datetime DEFAULT NULL,
  `zbozi_url` varchar(200) COLLATE utf8_czech_ci DEFAULT NULL,
  `inventura_user_id` int(11) DEFAULT NULL,
  `inventura` datetime DEFAULT NULL,
  `sazba_dph_id` int(11) NOT NULL DEFAULT '1',
  `vyrobce_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`zbozi_id`),
  UNIQUE KEY `ean` (`ean`),
  UNIQUE KEY `externi_id` (`externi_id`),
  KEY `typ_zbozi_id` (`typ_zbozi_id`)
);

CREATE TABLE IF NOT EXISTS `zbozi_dodavatel` (
  `zbozi_id` int(11) NOT NULL,
  `dodavatel_id` int(11) NOT NULL,
  `mnozstvi` int(11) DEFAULT NULL,
  `pocet_dni` int(11) DEFAULT NULL,
  `last_updated` datetime DEFAULT NULL,
  PRIMARY KEY (`zbozi_id`,`dodavatel_id`)
);

CREATE TABLE IF NOT EXISTS `zbozi_sada` (
  `zbozi_id` int(11) NOT NULL,
  `sada_id` int(11) NOT NULL,
  `mnozstvi` int(11) NOT NULL DEFAULT '1',
  `posledni_skladova_cena` float DEFAULT NULL,
  PRIMARY KEY (`zbozi_id`,`sada_id`)
);

CREATE TABLE IF NOT EXISTS `zbozi_sklad` (
  `zbozi_id` int(11) NOT NULL,
  `sklad_id` int(11) NOT NULL,
  `mnozstvi` int(11) NOT NULL DEFAULT '0',
  `skladova_cena` float DEFAULT NULL,
  PRIMARY KEY (`zbozi_id`,`sklad_id`)
);

CREATE TABLE IF NOT EXISTS `zbozi_sklad_stav` (
  `zbozi_sklad_stav_id` int(11) NOT NULL AUTO_INCREMENT,
  `zbozi_id` int(11) NOT NULL,
  `sklad_id` int(11) NOT NULL,
  `mnozstvi` int(11) NOT NULL,
  `cas` datetime NOT NULL,
  `konecna_cena` float DEFAULT NULL,
  `cena` float DEFAULT NULL,
  `id_dokladu` int(11) DEFAULT NULL,
  `typ_dokladu` varchar(30) COLLATE utf8_czech_ci DEFAULT NULL,
  `user_id` int(11) DEFAULT NULL,
  `duvod` varchar(100) COLLATE utf8_czech_ci DEFAULT NULL,
  `konecna_skladova_cena` float DEFAULT NULL,
  `celkove_mnozstvi` int(11) DEFAULT NULL,
  `edit_user_id` int(11) DEFAULT NULL,
  `poznamka` varchar(200) COLLATE utf8_czech_ci DEFAULT NULL,
  `dph` float NOT NULL DEFAULT '21',
  `platce_dph` tinyint(1) NOT NULL DEFAULT '0',
  `dph_zbozi` float NOT NULL DEFAULT '21',
  PRIMARY KEY (`zbozi_sklad_stav_id`),
  KEY `zbozi_id` (`zbozi_id`),
  KEY `id_dokladu` (`id_dokladu`)
);
